NativeBackend

Struct NativeBackend 

pub struct NativeBackend { /* private fields */ }
Native x86 interpreter backend backed by the Rust port of v86’s CPU core.

The current adapter is deliberately single-machine: the v86 CPU core uses process-global pointers, so two NativeBackend instances must not execute at the same time in one process.

Implementations

Source

impl NativeBackend

pub fn new() -> Self

pub fn with_instructions_per_step(self, value: u32) -> Self

pub fn cpu(&self) -> Option<&NativeCpu>

pub fn cpu_mut(&mut self) -> Option<&mut NativeCpu>

pub fn with_9p_root(self, path: impl AsRef<Path>) -> Self

pub fn set_9p_root(&mut self, path: impl AsRef<Path>) -> Result<()>