pub struct SavedState { /* private fields */ }Implementations
Sourceimpl SavedState
impl SavedState
pub fn from_bytes(bytes: impl Into<Vec<u8>>) -> Result<Self>
pub fn from_file(path: impl AsRef<Path>) -> Result<Self>
pub fn header(&self) -> StateHeader
pub fn metadata(&self) -> &Value
pub fn encoded_bytes(&self) -> &[u8] ⓘ
pub fn decoded_bytes(&self) -> &[u8] ⓘ
pub fn is_compressed(&self) -> bool
pub fn source(&self) -> Option<&Path>
pub fn buffer_count(&self) -> usize
pub fn memory_bytes(&self) -> Option<u64>
Sourcepub fn cpu_state_and_buffers(&self) -> Result<(Value, Vec<Vec<u8>>)>
pub fn cpu_state_and_buffers(&self) -> Result<(Value, Vec<Vec<u8>>)>
Return the raw v86 state array and typed buffers in buffer_id order. The buffers are copied out of the decoded state so callers can safely hand them to a native backend with its own lifetime.
pub fn sha256(&self) -> String
pub fn summary(&self) -> StateSummary
pub fn write_decoded(&self, path: impl AsRef<Path>) -> Result<()>